@@ -11,7 +11,7 @@ def bowyer(_mapping_fact, _mapping_to_convert):
     A function that given a function in the form 
     f(tree) will convert a one level tree in your mapping"""
     _toc = _mapping_fact(_mapping_to_convert)
-    for k, v in _toc.iteritems():
+    for k, v in _toc.items():
         if isinstance(v, Mapping):
             _toc[k] = bowyer(_mapping_fact, v)
     return _toc
@@ -22,7 +22,7 @@ def mapping_row_iter(tree, path=None):
     a list of ordered key that leads to the element and the value"""
     if path is None: path = []
 
-    for k, v in tree.iteritems():
+    for k, v in tree.items():
         if isinstance(v, Mapping):
             for child in mapping_row_iter(v, (path + [k])):
                 yield child
